@@ -1,6 +1,5 @@
 from datetime import datetime
 from typing import Any, Dict, Mapping, List, Sequence, Union
-import plistlib
 
 __all__ = (
     'ComplexInnerTypes',
@@ -10,12 +9,12 @@ __all__ = (
 )
 
 ComplexInnerTypes = Union[Sequence[Any], Mapping[str, Any], bytes]
-PlistValue = Union[plistlib.Data, Mapping[str, Any], Sequence[Any], bool, int,
-                   float, str, datetime, bytes]
+PlistValue = Union[Mapping[str, Any], Sequence[Any], bool, int, float, str,
+                   datetime, bytes]
 PlistList = Sequence[PlistValue]
 PlistRoot = Mapping[str, PlistValue]
 
-MutablePlistValue = Union[plistlib.Data, Dict[str, Any], List[Any], bool, int,
-                          float, str, datetime, bytes]
+MutablePlistValue = Union[Dict[str, Any], List[Any], bool, int, float, str,
+                          datetime, bytes]
 MutablePlistList = List[MutablePlistValue]
 MutablePlistRoot = Dict[str, MutablePlistValue]
